-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-- Written by Kimberly L. Tripp, SQLskills.com
-- All Rights Reserved.
-- 
-- For more scripts, sample code and additional training resources,
-- go to http://www.SQLskills.com
--	Immerse yourself in SQL Server
--
-- Disclaimer - Thoroughly test this script, execute at your own risk.
-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

-- Compare and contrast missing index DMVs vs DTA.

USE CREDIT
go

-- These samples use the Credit database. You can download and restore the
-- credit database from here:
-- http://www.sqlskills.com/resources/conferences/CreditBackup80.zip

-- NOTE: This is a SQL Server 2000 backup and MANY examples will work on 
-- SQL Server 2000 in addition to SQL Server 2005.

-- Let's start to analyze some queries and their performance:
SET STATISTICS IO ON
go

SELECT c.statement_no
		, s.statement_dt
		, c.charge_amt
		, p.provider_name
		, m.lastname
	FROM dbo.Charge AS c WITH (INDEX (0))
		INNER JOIN dbo.provider AS p WITH (INDEX (0))
			ON p.provider_no = c.provider_no
		INNER JOIN dbo.member AS m WITH (INDEX (0))
			ON c.member_no = m.member_no
		INNER JOIN dbo.statement AS s WITH (INDEX (0))
			ON c.statement_no = s.statement_no
		INNER JOIN dbo.region AS r WITH (INDEX (0))
			ON r.region_no = m.region_no
WHERE r.region_name = 'Japan'
	AND c.charge_amt > 2500
OPTION (MAXDOP 1)
go

-- The Missing Index DMVs Index (the green recommendation in Showplan)
--CREATE NONCLUSTERED INDEX MissingIndexDMVIndex
--ON [dbo].[charge] ([charge_amt])
--INCLUDE ([member_no],[provider_no],[statement_no])
--GO

SELECT c.statement_no
		, s.statement_dt
		, c.charge_amt
		, p.provider_name
		, m.lastname
	FROM dbo.Charge AS c WITH (INDEX (MissingIndexDMVIndex))
		INNER JOIN dbo.provider AS p 
			ON p.provider_no = c.provider_no
		INNER JOIN dbo.member AS m 
			ON c.member_no = m.member_no
		INNER JOIN dbo.statement AS s 
			ON c.statement_no = s.statement_no
		INNER JOIN dbo.region AS r 
			ON r.region_no = m.region_no
WHERE r.region_name = 'Japan'
	AND c.charge_amt > 2500
OPTION (MAXDOP 1)
go

-- DTA's recommended index (highlight the query and choose Q, Analyze in DTA)
--CREATE NONCLUSTERED INDEX DTAIndexRec 
--ON [dbo].[charge] ([member_no], [charge_amt],[provider_no], [statement_no])


SELECT c.statement_no
		, s.statement_dt
		, c.charge_amt
		, p.provider_name
		, m.lastname
	FROM dbo.Charge AS c 
		INNER JOIN dbo.provider AS p 
			ON p.provider_no = c.provider_no
		INNER JOIN dbo.member AS m 
			ON c.member_no = m.member_no
		INNER JOIN dbo.statement AS s 
			ON c.statement_no = s.statement_no
		INNER JOIN dbo.region AS r 
			ON r.region_no = m.region_no
WHERE r.region_name = 'Japan'
	AND c.charge_amt > 2500
OPTION (MAXDOP 1)
go